@@ -54,15 +54,15 @@ def _try_unit(unit):
     else:
         return unit
 
-
+@vaex.dataset.register
 class Hdf5MemoryMapped(DatasetMemoryMapped):
+    snake_name = "hdf5"
     """Implements the vaex hdf5 file format"""
 
-    def __init__(self, path, write=False, fs_options={}, fs=None):
-        nommap = not vaex.file.memory_mappable(path)
-        self.fs_options = fs_options
-        self.fs = fs
-        super(Hdf5MemoryMapped, self).__init__(vaex.file.stringyfy(path), write=write, nommap=nommap)
+    def __init__(self, path, write=False, fs_options={}, fs=None, nommap=None):
+        if nommap is None:
+            nommap = not vaex.file.memory_mappable(path)
+        super(Hdf5MemoryMapped, self).__init__(vaex.file.stringyfy(path), write=write, nommap=nommap, fs_options=fs_options, fs=fs)
         self._all_mmapped = True
         self._open(path)
         self.units = {}
@@ -85,13 +85,10 @@ class Hdf5MemoryMapped(DatasetMemoryMapped):
         self.h5file = h5py.File(file, "r+" if self.write else "r")
 
 
-    def __getstate__(self):
-        return {
-            **super().__getstate__(),
-            'nommap': self.nommap,
-            'fs_options': self.fs_options,
-            'fs': self.fs,
-        }
+    @classmethod
+    def decode(cls, encoding, spec):
+        ds = cls(**spec)
+        return ds
 
     def __setstate__(self, state):
         super().__setstate__(state)
